# Automated Research Assistant

![PyPI](https://img.shields.io/pypi/v/autora)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/autoresearch/autora/test-pytest.yml)
![PyPI - Downloads](https://img.shields.io/pypi/dm/autora)

<b>[AutoRA](https://pypi.org/project/autora/)</b> (<b>Auto</b>mated <b>R</b>esearch <b>A</b>ssistant) is an open-source framework for 
automating multiple stages of the empirical research process, including model discovery, experimental design, data collection, and documentation for open science.

![Autonomous Empirical Research Paradigm](https://github.com/AutoResearch/autora/raw/restructure/autora/docs/img/overview.png)

## Getting Started

Check out the documentation at 
[https://autoresearch.github.io/autora](https://autoresearch.github.io/autora).

## About

This project is in active development by 
the [Autonomous Empirical Research Group](http://empiricalresearch.ai), 
led by [Sebastian Musslick](https://smusslick.com), 
in collaboration with the [Center for Computation and Visualization at Brown University](https://ccv.brown.edu).

The development of this package is supported by Schmidt Science Fellows, in partnership with the Rhodes Trust, as well as the Carney BRAINSTORM program at Brown University.

## Read More

- [Package Documentation](https://autoresearch.github.io/autora/)
- [AutoRA Pip Package](https://pypi.org/project/autora/)
- [Autonomous Empirical Research Group](http://www.empiricalresearch.ai)

